@import url(error.css);

hr { 
  display: none;
}

#main {
  border-bottom: 1px solid rgba(255,255,255,0.5);
}

#links {
  display: table;
  text-align: right;
  width: 100%;
  padding: 25px 0;
  border-bottom: 1px solid rgba(0,130,217,0.2);
}

#links button {
  vertical-align: middle;
  float: left;
  width: auto;
}

#links a {
  white-space: nowrap;
  margin: 0 0 0 10px;
}

iframe {
  width: 500px;
  height: 100px;
  border: none;
  margin: 10px 0 -30px 0;
}