@charset "utf-8";
/* Stylesheet for the Opera media viewer */
/* Copyright 2010 Opera Software */
html {
	background-color: hsl(0,0%,98%);
	width: 100%;
	height: 100%;
	display: table;
}
body {
	margin: 0;
	height: 100%;
	display: table-row;
}
div {
	vertical-align: middle;
	height: 100%;
	display: table-cell;
}
video, audio {
	margin: auto;
	display: block;
}
@media projection, tv, handheld {
	html {background-color: black;}
	body {background-color: hsl(0,0%,39%);}
	video, audio {background-color: hsl(0,0%,98%);}
}
@media tv, handheld and (max-width: 300px) {
	html {
		margin: auto;
		width: 246px;
		max-width: 100%;
	}
	video, audio {
		margin: 10px auto;
		max-width: 100%;
	}
}

