@charset "utf-8";
/* Shared Stylesheet for internal Opera documents */
/* Copyright 2011 Opera Software */

@import url(opera.css);

body {
  overflow: visible;
}

h2 img {
  float: left;
  width: 16px;
  height: 16px;
  margin: 4px 6px 0 0px;
}

p { 
  word-wrap: break-word;
}

form {
  display: block;
  padding: 3px;
  border-radius: 4px;
  background-color: rgba(227,232,236,0.4);
  border: 1px solid rgba(175,188,203,0.5);
  display: table;
  width: 100%;
}

input[type="text"] {
  border: 1px solid #afbccb;      
  border-radius: 3px;
  padding: 5px;
  height: 26px;
  display: table-cell;
  width: 99%;
  margin-right: 10px;
}

input[type="text"]:hover, input[type="text"]:focus {
  border-color: #69b;
  color: #000;
}

button {
  width: 10px;
  display: table-cell;
  padding: 2px 20px;
  font-weight: bold;
  background: #dae2ec;
  border: 1px solid #afbccb; 
  border-radius: 3px;
  box-shadow: 0 1px 2px rgba(175,188,203,0.6), inset 0 10px 15px rgba(255,255,255,0.5), inset 1px 1px rgba(255,255,255,0.5), inset -1px -1px rgba(255,255,255,0.5);
  text-shadow: 0 1px rgba(255,255,255,0.5);
}

button:hover, button:focus {
  background-color: #adf;
  border-color: #69b;
  color: #000;
}

#searchSuggestions {
  line-height: 2em;
  padding: 0;
  margin: 0;
}

#searchSuggestions li {
  margin: 10px 0 0 0;
  background: none;
}

#learnmore {
  position: relative;
  top: 6em;
  margin-top: -3em;
  text-align: center;
}

cite {
  display: inline;
}

pre {
  word-wrap: break-word;
  font-family: Consolas,Menlo,monospace;
}
