@charset "utf-8";
/*	Name: -1902163789 */
/*	Page layout inspector - floats. 
	Resets the float property to 'none' for all elements.
	Copyright 2009 Opera Software */
*, *::before, *::after {
	float: none !important;
}

