@import url(opera.css);
@media tv {html {font-size: 150%;}}


html {
	background: #d7dee5;
	color: #000;
	height: auto;
	line-height: 1.4;
}

body {
	max-width: 100%;
	padding: 0 0 10px 0;
	margin: 5px;
	background: #fff;
	outline: 1px solid #cdd5de;
}

td, th {
	color: #333;
	font-size: 90%;
	line-height: 1.3;
	padding: 4px 6px;
}
th {
	width: 30%;
	color: #777;
} 
td {
	text-overflow: ellipsis;
	overflow: hidden;
}

h1 {
	font-size: 120%;
	background: none;
	margin: 0 0 1em 0;
	letter-spacing: 0;
	font-weight: bold;
	color: #121212;
	padding: 6px 8px;
	line-height: 1.3;
}

h2 {
	margin: 0 8px;
	font-size: 100%;
	border-bottom: 1px solid #cdd5de;
	letter-spacing: 0;
}

ul { padding: 0 8px; }
ul li { background: url(images/file.png) no-repeat 0 0.3em; }

li a {
	text-overflow: ellipsis;
	margin: 5px 1%;
	overflow: hidden;
	max-width: 95%;
	display: block;
}

@media print {
	* {font-size: 10pt;}
	h1, h2 {
		font-size: 16pt;
		text-align:center;
	}
	th, td {
		text-align: left;
		vertical-align: top;
		display: table-row;
	}
	html[dir="rtl"] th, html[dir="rtl"] td {text-align: right;}
}


